summaryrefslogtreecommitdiffstats
path: root/kig/misc/calcpaths.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/calcpaths.cc')
-rw-r--r--kig/misc/calcpaths.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/kig/misc/calcpaths.cc b/kig/misc/calcpaths.cc
index 3e947789..1532715b 100644
--- a/kig/misc/calcpaths.cc
+++ b/kig/misc/calcpaths.cc
@@ -75,7 +75,7 @@ void localdfs( ObjectCalcer* obj,
std::vector<ObjectCalcer*>& all)
{
visited.push_back( obj );
- const std::vector<ObjectCalcer*> o = obj->tqchildren();
+ const std::vector<ObjectCalcer*> o = obj->children();
for ( std::vector<ObjectCalcer*>::const_iterator i = o.begin(); i != o.end(); ++i )
{
if ( std::find( visited.begin(), visited.end(), *i ) == visited.end() )
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
// we put all of its tqchildren at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -115,7 +115,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
{
for ( std::vector<ObjectCalcer*>::const_iterator i = tmp.begin(); i != tmp.end(); ++i )
{
- const std::vector<ObjectCalcer*> o = (*i)->tqchildren();
+ const std::vector<ObjectCalcer*> o = (*i)->children();
std::copy( o.begin(), o.end(), std::back_inserter( all ) );
std::copy( o.begin(), o.end(), std::back_inserter( tmp2 ) );
};
@@ -148,7 +148,7 @@ bool addBranch( const std::vector<ObjectCalcer*>& o, const ObjectCalcer* to, std
if ( *i == to )
rb = true;
else
- if ( addBranch( (*i)->tqchildren(), to, ret ) )
+ if ( addBranch( (*i)->children(), to, ret ) )
{
rb = true;
ret.push_back( *i );
@@ -163,7 +163,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& from, con
for ( std::vector<ObjectCalcer*>::const_iterator i = from.begin(); i != from.end(); ++i )
{
- (void) addBranch( (*i)->tqchildren(), to, all );
+ (void) addBranch( (*i)->children(), to, all );
};
std::vector<ObjectCalcer*> ret;
@@ -193,7 +193,7 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// this function returns true if the visited object depends on one
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
// but their direct tqchildren do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
std::vector<bool> deps( o->parents().size(), false );
@@ -289,8 +289,8 @@ std::set<ObjectCalcer*> getAllChildren( const std::vector<ObjectCalcer*> objs )
i != cur.end(); ++i )
{
ret.insert( *i );
- std::vector<ObjectCalcer*> tqchildren = (*i)->tqchildren();
- next.insert( tqchildren.begin(), tqchildren.end() );
+ std::vector<ObjectCalcer*> children = (*i)->children();
+ next.insert( children.begin(), children.end() );
};
cur = next;
};
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
- // we put all of its tqchildren at the end of it, and we do the same
+ // we put all of its children at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -193,7 +193,7 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
- // but their direct tqchildren do ), then we add them to ret.
+ // but their direct children do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
std::vector<bool> deps( o->parents().size(), false );